@@ -1,8 +1,6 @@
-pub mod demo;
-pub mod event;
-mod image;
-mod manifest;
-pub mod messagebox;
 pub mod natives_and_messaging;
-pub mod nxui;
-pub mod window;
+pub mod demo;
+
+pub mod messagebox;
+mod window;
+pub mod nxui;
\ No newline at end of file
